# Datasets

```{eval-rst}
.. module:: ehrdata
    :no-index:
```

```{eval-rst}
.. autosummary::
    :toctree: data
    :nosignatures:

    dt.ehrdata_blobs
    dt.mimic_iv_omop
    dt.gibleed_omop
    dt.synthea27nj_omop
    dt.physionet2012
    dt.mimic_2
    dt.mimic_2_preprocessed
    dt.diabetes_130_raw
    dt.diabetes_130_fairlearn
```
